"""
Generic exception class for raising custom exceptions
"""


class SSSException(Exception):
    pass
